package com.engine.sskj.service.impl;

import com.engine.core.impl.Service;
import com.engine.sskj.service.EntryService;
import org.apache.commons.lang.StringUtils;
import weaver.conn.RecordSet;
import weaver.general.Util;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class EntryServiceImpl extends Service implements EntryService {
    @Override
    public Map<String, Object> checkBlackList(Map<String, Object> params) {
        Map<String, Object> result = new HashMap<>();

        RecordSet rs = new RecordSet();

        String idNumbers = Util.null2String(params.get("idNumbers"));//获取入参中的身份证号

        if ( StringUtils.isBlank(idNumbers)) {
            result.put("code",500);
            result.put("msg","未获取到身份证号。");
            return result;
        }

        List<String> inList = new ArrayList<>();
        String[] idNumbersArr = idNumbers.split(",");
        for (String idNumber:idNumbersArr) {
            Integer number = -1;
            String checkSql = "select count(*) as number from uf_entryblacklist where sfzh = ? ";
            rs.executeQuery(checkSql,idNumber);
            while (rs.next()) {
                number = Util.getIntValue(Util.null2String(rs.getString("number")));
            }
            if ( number > 0 ) {//在黑名单中
                inList.add(idNumber);
            }
        }

        if ( !inList.isEmpty()) {
            String inStr = String.join(",",inList);
            result.put("code",500);
            result.put("msg","身份证号:"+inStr+" 在黑名单中，是否继续入职申请？");
            return result;
        }

        result.put("code",200);
        result.put("msg","该批人员身份证号均不在黑名单中。");
        return result;
    }

    @Override
    public Map<String, Object> checkEntryStatus(Map<String, Object> params) {
        Map<String, Object> result = new HashMap<>();
        RecordSet rs = new RecordSet();

        String dataIds = Util.null2String(params.get("dataIds"));

        if (StringUtils.isEmpty(dataIds)) {
            result.put("code",500);
            result.put("msg","未选择需要检测入职状态的员工");
            return result;
        }

        String[] idsArr = dataIds.split(",");

        List<String> errorStatusList = new ArrayList<>();
        List<String> errorPromptList = new ArrayList<>();

        String checkStatusSql = "select rzzt,xm from uf_rzgl where id = ?";
        for (String id: idsArr) {
            rs.executeQuery(checkStatusSql,id);
            while (rs.next()) {
                Integer status = Util.getIntValue(Util.null2String(rs.getString("rzzt")));
                String lastname = Util.null2String(rs.getString("xm"));
                if (status != 0 ) {
                    errorStatusList.add(id);
                    errorPromptList.add(lastname);
                }
            }
        }

        if ( !errorStatusList.isEmpty()) {//存在不为待入职状态的数据
            String prompStr = String.join(",",errorPromptList);
            result.put("code",500);
            result.put("msg","姓名为："+prompStr+" 的人员，入职状态不出于待入职状态，不可以办理入职。");//确认一下需要提示什么
            return result;
        }

        result.put("code",200);
        result.put("msg","均可办理入职");
        return result;
    }
}
